@@ -219,7 +219,7 @@ class InterfaceFileHandling:
             else:
                 return messages.message["upload_failed"]
 
-    def download_file(self, location, filename):
+    def download_file(self, filename):
 
         src_blob = BlobClient(
             self.blob_service_client.url,
@@ -246,6 +246,6 @@ class InterfaceFileHandling:
         if result["code"] == "OK":
             for file in files:
                 print("Downloading file >%s< from location >%s<" % (file, location))
-                self.download_file(location=location, filename=file)
+                self.download_file(filename=file)
         else:
             print("An error occurred listing files", result)
